@@ -1,6 +1,5 @@
 from .config import Config
 from .document import Document
-from .exception import LivemarkException
 from .markup import Markup
 from .plugin import Plugin
 from .project import Project
@@ -9,3 +8,4 @@ from .server import Server
 from .settings import VERSION as __version__
 from .snippet import Snippet
 from .system import system
+from . import errors
