@@ -2,11 +2,14 @@ import re
 import yaml
 import difflib
 from frictionless import File
-from .exception import LivemarkException
 from .config import Config
 from .system import system
 from . import settings
 from . import helpers
+from . import errors
+
+
+# TODO: make document required or initialize it
 
 
 class Document:
@@ -24,7 +27,7 @@ class Document:
 
     """
 
-    def __init__(self, source, *, target=None, format=None, name=None):
+    def __init__(self, source, *, target=None, format=None):
 
         # Infer target
         if not target:
@@ -47,7 +50,6 @@ class Document:
         self.__content = None
         self.__input = None
         self.__output = None
-        self.__name = name
 
     def __setattr__(self, name, value):
         if name == "project":
@@ -61,57 +63,119 @@ class Document:
 
     @property
     def source(self):
+        """Document's source
+
+        Returns:
+            str: source
+        """
         return self.__source
 
     @property
     def target(self):
+        """Document's target
+
+        Returns:
+            str: target
+        """
         return self.__target
 
     @property
     def format(self):
+        """Document's format
+
+        Returns:
+            str: format
+        """
         return self.__format
 
     @property
     def project(self):
+        """Document's project
+
+        Returns:
+            Project: project
+        """
         return self.__project
 
     @property
     def plugins(self):
+        """Document's plugins
+
+        Returns:
+            Plugin[]?: plugins
+        """
         return self.__plugins
 
     @property
     def input(self):
+        """Document's input
+
+        Returns:
+            str?: input
+        """
         return self.__input
 
     @property
     def output(self):
+        """Document's output
+
+        Returns:
+            str?: output
+        """
         return self.__output
 
     @property
     def preface(self):
+        """Document's preface
+
+        Returns:
+            str?: preface
+        """
         return self.__preface
 
     @property
     def content(self):
+        """Document's content
+
+        Returns:
+            str?: content
+        """
         return self.__content
 
     @property
     def config(self):
+        """Document's config
+
+        Returns:
+            Config?: config
+        """
         return self.__config
 
     @property
     def name(self):
-        name = self.__name
-        if not name:
-            name = self.title if self.content else self.path
-        return name
+        """Document's name
+
+        Returns:
+            str: name
+        """
+        return self.title or self.path
 
     @property
     def path(self):
+        """Document's path
+
+        Returns:
+            str: path
+        """
         return helpers.with_format(self.source, "")
 
     @property
     def title(self):
+        """Document's title
+
+        Returns:
+            str?: title
+        """
         if self.content:
             prefix = "# "
             for line in self.content.splitlines():
@@ -120,6 +184,11 @@ class Document:
 
     @property
     def description(self):
+        """Document's description
+
+        Returns:
+            str?: description
+        """
         if self.content:
             pattern = re.compile(r"^\w")
             for line in self.content.splitlines():
@@ -129,12 +198,26 @@ class Document:
 
     @property
     def keywords(self):
+        """Document's keywords
+
+        Returns:
+            str?: keywords
+        """
         if self.content:
             return ",".join(map(str.lower, self.title.split()))
 
     # Build
 
     def build(self, *, diff=False, print=False):
+        """Build the document
+
+        Parameters:
+            diff (bool): print the diff
+            print (bool): print the result
+
+        Returns:
+            str: output
+        """
         self.read()
         self.process()
         output = self.write(diff=diff, print=print)
@@ -143,6 +226,7 @@ class Document:
     # Read
 
     def read(self):
+        """Read the document"""
 
         # Read input
         with open(self.__source) as file:
@@ -166,27 +250,39 @@ class Document:
         # Create plugins
         if self.__plugins is None:
             self.__plugins = []
-            for name, Plugin in system.Plugins.items():
-                type = Plugin.get_type()
-                internal = type == "internal" and name not in self.__config.disable
-                external = type == "external" and name in self.__config.enable
-                if internal or external:
+            for Plugin in system.iterate():
+                if Plugin.check_status(self.__config):
                     self.__plugins.append(Plugin(self))
-            self.__plugins = helpers.order_objects(self.__plugins, "priority")
 
     # Process
 
     def process(self):
+        """Process the document"""
+
+        # Ensure read
         if self.__content is None:
-            raise LivemarkException("Read document before processing")
+            raise errors.Error("Read document before processing")
+
+        # Iterate plugins
         for plugin in self.__plugins:
             plugin.process_document(self)
 
     # Write
 
     def write(self, *, diff=False, print=False):
+        """Write the document
+
+        Parameters:
+            diff (bool): print the diff
+            print (bool): print the result
+
+        Returns:
+            str: output
+        """
+
+        # Ensure processed
         if self.__output is None:
-            raise LivemarkException("Process document before writing")
+            raise errors.Error("Process document before writing")
 
         # Diff
         if diff:
@@ -213,14 +309,11 @@ class Document:
     # Helpers
 
     def get_plugin(self, name):
-        for plugin in self.plugins:
-            if plugin.name == name:
-                return plugin
+        """Get document's plugin by name
 
-    def with_format(self, format):
-        return Document(
-            self.__source,
-            target=self.__target,
-            format=format,
-            name=self.__name,
-        )
+        Parameters:
+            name (str): plugin name
+        """
+        for plugin in self.plugins:
+            if plugin.identity == name:
+                return plugin
