@@ -3,9 +3,9 @@ from ...plugin import Plugin
 
 
 class LinksPlugin(Plugin):
-    name = "links"
+    identity = "links"
     priority = 10
-    profile = {
+    validity = {
         "type": "object",
         "properties": {
             "items": {
@@ -23,14 +23,17 @@ class LinksPlugin(Plugin):
 
     # Context
 
-    @Plugin.property
+    @property
     def items(self):
         github = self.document.get_plugin("github")
         items = deepcopy(self.config.get("items", []))
         if github:
-            items.append({"name": "Report", "path": github.report_url})
-            items.append({"name": "Fork", "path": github.fork_url})
-            items.append({"name": "Edit", "path": github.edit_url})
+            if github.report_url:
+                items.append({"name": "Report", "path": github.report_url})
+            if github.fork_url:
+                items.append({"name": "Fork", "path": github.fork_url})
+            if github.edit_url:
+                items.append({"name": "Edit", "path": github.edit_url})
         return items
 
     # Process
