@@ -4,11 +4,15 @@ import typer
 from ..server import Server
 from ..project import Project
 from ..document import Document
-from ..exception import LivemarkException
 from .main import program
+from .. import errors
 from . import common
 
 
+# NOTE:
+# Live mode always opens index file even though another source is provided
+
+
 @program.command(name="build")
 def program_build(
     source: str = common.source,
@@ -29,7 +33,7 @@ def program_build(
         if not os.path.exists(config):
             if not source:
                 message = 'Project without config requires "source" argument'
-                raise LivemarkException(message)
+                raise errors.Error(message)
 
         # Create project
         document = None
